--
-- Copyright (C) 2009-2016 John MacFarlane, Hans Hagen
--
-- Permission is hereby granted, free of charge, to any person obtaining
-- a copy of this software and associated documentation files (the
-- "Software"), to deal in the Software without restriction, including
-- without limitation the rights to use, copy, modify, merge, publish,
-- distribute, sublicense, and/or sell copies of the Software, and to
-- permit persons to whom the Software is furnished to do so, subject to
-- the following conditions:
--
-- The above copyright notice and this permission notice shall be
-- included in all copies or substantial portions of the Software.
--
-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
-- MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE AND NONINFRINGEMENT.
-- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
-- CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
-- TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-- SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
--
-- Copyright (C) 2016-2024 Vít Starý Novotný, Andrej Genčur
--
-- This work may be distributed and/or modified under the
-- conditions of the LaTeX Project Public License, either version 1.3
-- of this license or (at your option) any later version.
-- The latest version of this license is in
--
--     http://www.latex-project.org/lppl.txt
--
-- and version 1.3 or later is part of all distributions of LaTeX
-- version 2005/12/01 or later.
--
-- This work has the LPPL maintenance status `maintained'.
-- The Current Maintainer of this work is Vít Starý Novotný.
--
-- Send bug reports, requests for additions and questions
-- either to the GitHub issue tracker at
--
--     https://github.com/witiko/markdown/issues
--
-- or to the e-mail address <witiko@mail.muni.cz>.
--
-- MODIFICATION ADVICE:
--
-- If you want to customize this file, it is best to make a copy of
-- the source file(s) from which it was produced. Use a different
-- name for your copy(ies) and modify the copy(ies); this will ensure
-- that your modifications do not get overwritten when you install a
-- new release of the standard system. You should also ensure that
-- your modified source file does not generate any modified file with
-- the same name as a standard file.
--
-- You will also need to produce your own, suitably named, .ins file to
-- control the generation of files from your source file; this file
-- should contain your own preambles for the files it generates, not
-- those in the standard .ins files.
--
local metadata = {
    version   = "3.8.1-0-gbbed72f3",
    comment   = "A module for the conversion from markdown "
             .. "to plain TeX",
    author    = "John MacFarlane, Hans Hagen, Vít Starý Novotný, "
             .. "Andrej Genčur",
    copyright = {"2009-2016 John MacFarlane, Hans Hagen",
                 "2016-2024 Vít Starý Novotný, Andrej Genčur"},
    license   = "LPPL 1.3c"
}

local lpeg = require("lpeg")
local M = {metadata = metadata}
M.punctuation = {}
local S = lpeg.S
-- luacheck: push no max line length
M.punctuation[1] = S([[!]]) + S([["]]) + S([[#]]) + S([[$]]) + S([[%]]) + S([[&]]) + S([[']]) + S([[(]]) + S([[)]]) + S([[*]]) + S([[+]]) + S([[,]]) + S([[-]]) + S([[.]]) + S([[/]]) + S([[:]]) + S([[;]]) + S([[<]]) + S([[=]]) + S([[>]]) + S([[?]]) + S([[@]]) + S([[[]]) + S([[\]]) + S(']') + S([[^]]) + S([[_]]) + S([[`]]) + S([[{]]) + S([[|]]) + S([[}]]) + S([[~]])
M.punctuation[2] = S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))
M.punctuation[3] = S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]])))
M.punctuation[4] = S([[]]) * (S([[]]) * (S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]))) + S([[]]) * (S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]])) + S([[]]) * (S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]) + S([[]]))))
-- luacheck: pop
return M
